@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12978 2021-06-16 09:15:13Z Becca $
+# $Id: __init__.py 12979 2021-06-16 09:44:47Z Becca $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Becca $ (last)
-# $Date: 2021-06-16 17:15:13 +0800 (Wed, 16 Jun 2021) $
-# $Revision: 12978 $
+# $Date: 2021-06-16 17:44:47 +0800 (Wed, 16 Jun 2021) $
+# $Revision: 12979 $
 
 from __future__ import print_function
 
@@ -1117,7 +1117,7 @@ def attachURLs(settings, urlpatterns, excludeApps=()):
             
     #==========================================================================
     # DEBUG toolbar
-    if settings.DEBUG_TOOLBAR_ENABLE == True:
+    if getattr(settings, 'DEBUG_TOOLBAR_ENABLE', None):
         try:
             import debug_toolbar
         except:
