@@ -21,15 +21,27 @@ import datetime
 import hashlib
 import json
 import six
+import zipfile
+import shutil
 
 from functools import wraps
 
 import scrapy
 
 STATIC_DIR = os.path.join('static')
+BACKUP_LIMIT = 100
+
+def sortDatetime(elem):
+    return elem[1]
 
 def toBytes(s):
     return s if six.PY2 else s.encode()
+    
+def zipdir(path, ziph):
+    # ziph is zipfile handle
+    for root, dirs, files in os.walk(path):
+        for file in files:
+            ziph.write(os.path.join(root, file))
 
 def saveHtml(func):
     @wraps(func)
@@ -157,6 +169,27 @@ class BaseSpider(scrapy.Spider):
                 raise KeyError("No date record: %s" % self.crawlDate)
         self.logger.info("----- Start %s %s -----" % (self.name, self.NOW))
         return rt
+        
+    def closed(self, *args, **kwargs):
+        self.logger.info("----- Zip %s %s -----" % (self.name, self.NOW))
+        
+        directory = os.path.join(
+            STATIC_DIR, str(self.TODAY))    
+        
+        try:
+            # zip
+            zipf = zipfile.ZipFile(
+                os.path.join(STATIC_DIR, "Backup_%s_%s.zip" % (self.name, str(self.TODAY))), 
+                'w', compresslevel=6, compression=zipfile.ZIP_BZIP2)
+            zipdir(directory, zipf)
+            zipf.close()
+            
+            # remove
+            shutil.rmtree(directory)
+        except Exception as e:
+            self.logger.error("Error zip: %s" % (e,))
+                
+        self.logger.info("----- End %s %s -----" % (self.name, self.NOW))
 
     def logger(self):
         logger = logging.getLogger(self.loggerName)
