@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12842 2021-04-09 08:30:54Z Lavender $
+# $Id: views.py 12858 2021-04-23 03:51:09Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2021-04-09 16:30:54 +0800 (Fri, 09 Apr 2021) $
-# $Revision: 12842 $ 
+# $Date: 2021-04-23 11:51:09 +0800 (Fri, 23 Apr 2021) $
+# $Revision: 12858 $ 
 
 import json
 import logging
@@ -260,7 +260,11 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
     # send mail
     if request:
         site = get_current_site(request)
-        msg = "%s: %s" % (_("Order number"), order_number)
+        msg = "%s: %s\n%s: %s" % (
+            _("Order number"), order_number, _("Order URL"), 
+            "%s://%s%s" % (request.scheme, site.domain, 
+                         reverse('dashboard:order-detail', kwargs={'number': order.number,}),)
+        )
         title = "[%s] %s" % (site.name, _("Customer order notification"))
         sendMessageToAdmin(str(title), msg)
    
